import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface OneDashboardConfig extends cdktf.TerraformMetaArguments {
    /**
     * The New Relic account ID where you want to create the dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The dashboard's description.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#description OneDashboard#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The dashboard's name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#name OneDashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Determines who can see or edit the dashboard. Valid values are private, public_read_only, public_read_write. Defaults to public_read_only.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#permissions OneDashboard#permissions}
     *
     * @stability stable
     */
    readonly permissions?: string;
    /**
     * page block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#page OneDashboard#page}
     *
     * @stability stable
     */
    readonly page: OneDashboardPage[] | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetAreaNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetAreaNrqlQueryToTerraform(struct?: OneDashboardPageWidgetAreaNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetArea {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetAreaNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetAreaToTerraform(struct?: OneDashboardPageWidgetArea | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBarNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetBarNrqlQueryToTerraform(struct?: OneDashboardPageWidgetBarNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBar {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Use this item to filter the current dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#filter_current_dashboard OneDashboard#filter_current_dashboard}
     *
     * @stability stable
     */
    readonly filterCurrentDashboard?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Related entities. Currently only supports Dashboard entities, but may allow other cases in the future.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#linked_entity_guids OneDashboard#linked_entity_guids}
     *
     * @stability stable
     */
    readonly linkedEntityGuids?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetBarNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetBarToTerraform(struct?: OneDashboardPageWidgetBar | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBillboardNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetBillboardNrqlQueryToTerraform(struct?: OneDashboardPageWidgetBillboardNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBillboard {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * The critical threshold value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#critical OneDashboard#critical}
     *
     * @stability stable
     */
    readonly critical?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * The warning threshold value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#warning OneDashboard#warning}
     *
     * @stability stable
     */
    readonly warning?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetBillboardNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetBillboardToTerraform(struct?: OneDashboardPageWidgetBillboard | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBulletNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetBulletNrqlQueryToTerraform(struct?: OneDashboardPageWidgetBulletNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetBullet {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * The maximum value for the visualization.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#limit OneDashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetBulletNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetBulletToTerraform(struct?: OneDashboardPageWidgetBullet | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetFunnelNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetFunnelNrqlQueryToTerraform(struct?: OneDashboardPageWidgetFunnelNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetFunnel {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetFunnelNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetFunnelToTerraform(struct?: OneDashboardPageWidgetFunnel | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetHeatmapNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetHeatmapNrqlQueryToTerraform(struct?: OneDashboardPageWidgetHeatmapNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetHeatmap {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetHeatmapNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetHeatmapToTerraform(struct?: OneDashboardPageWidgetHeatmap | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetHistogramNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetHistogramNrqlQueryToTerraform(struct?: OneDashboardPageWidgetHistogramNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetHistogram {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetHistogramNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetHistogramToTerraform(struct?: OneDashboardPageWidgetHistogram | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetJsonNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetJsonNrqlQueryToTerraform(struct?: OneDashboardPageWidgetJsonNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetJson {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetJsonNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetJsonToTerraform(struct?: OneDashboardPageWidgetJson | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetLineNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetLineNrqlQueryToTerraform(struct?: OneDashboardPageWidgetLineNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetLine {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetLineNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetLineToTerraform(struct?: OneDashboardPageWidgetLine | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetMarkdown {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#text OneDashboard#text}.
     *
     * @stability stable
     */
    readonly text?: string;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
}
export declare function oneDashboardPageWidgetMarkdownToTerraform(struct?: OneDashboardPageWidgetMarkdown | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetPieNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetPieNrqlQueryToTerraform(struct?: OneDashboardPageWidgetPieNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetPie {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Use this item to filter the current dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#filter_current_dashboard OneDashboard#filter_current_dashboard}
     *
     * @stability stable
     */
    readonly filterCurrentDashboard?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Related entities. Currently only supports Dashboard entities, but may allow other cases in the future.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#linked_entity_guids OneDashboard#linked_entity_guids}
     *
     * @stability stable
     */
    readonly linkedEntityGuids?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetPieNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetPieToTerraform(struct?: OneDashboardPageWidgetPie | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetStackedBarNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetStackedBarNrqlQueryToTerraform(struct?: OneDashboardPageWidgetStackedBarNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetStackedBar {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetStackedBarNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetStackedBarToTerraform(struct?: OneDashboardPageWidgetStackedBar | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetTableNrqlQuery {
    /**
     * The account id used for the NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#account_id OneDashboard#account_id}
     *
     * @stability stable
     */
    readonly accountId?: number;
    /**
     * The NRQL query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#query OneDashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function oneDashboardPageWidgetTableNrqlQueryToTerraform(struct?: OneDashboardPageWidgetTableNrqlQuery | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPageWidgetTable {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#column OneDashboard#column}.
     *
     * @stability stable
     */
    readonly column: number;
    /**
     * Use this item to filter the current dashboard.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#filter_current_dashboard OneDashboard#filter_current_dashboard}
     *
     * @stability stable
     */
    readonly filterCurrentDashboard?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#height OneDashboard#height}.
     *
     * @stability stable
     */
    readonly height?: number;
    /**
     * Related entities. Currently only supports Dashboard entities, but may allow other cases in the future.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#linked_entity_guids OneDashboard#linked_entity_guids}
     *
     * @stability stable
     */
    readonly linkedEntityGuids?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#row OneDashboard#row}.
     *
     * @stability stable
     */
    readonly row: number;
    /**
     * A title for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#title OneDashboard#title}
     *
     * @stability stable
     */
    readonly title: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#width OneDashboard#width}.
     *
     * @stability stable
     */
    readonly width?: number;
    /**
     * nrql_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#nrql_query OneDashboard#nrql_query}
     *
     * @stability stable
     */
    readonly nrqlQuery: OneDashboardPageWidgetTableNrqlQuery[] | cdktf.IResolvable;
}
export declare function oneDashboardPageWidgetTableToTerraform(struct?: OneDashboardPageWidgetTable | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface OneDashboardPage {
    /**
     * The dashboard page's description.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#description OneDashboard#description}
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * The dashboard page's name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#name OneDashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * widget_area block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_area OneDashboard#widget_area}
     *
     * @stability stable
     */
    readonly widgetArea?: OneDashboardPageWidgetArea[] | cdktf.IResolvable;
    /**
     * widget_bar block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_bar OneDashboard#widget_bar}
     *
     * @stability stable
     */
    readonly widgetBar?: OneDashboardPageWidgetBar[] | cdktf.IResolvable;
    /**
     * widget_billboard block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_billboard OneDashboard#widget_billboard}
     *
     * @stability stable
     */
    readonly widgetBillboard?: OneDashboardPageWidgetBillboard[] | cdktf.IResolvable;
    /**
     * widget_bullet block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_bullet OneDashboard#widget_bullet}
     *
     * @stability stable
     */
    readonly widgetBullet?: OneDashboardPageWidgetBullet[] | cdktf.IResolvable;
    /**
     * widget_funnel block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_funnel OneDashboard#widget_funnel}
     *
     * @stability stable
     */
    readonly widgetFunnel?: OneDashboardPageWidgetFunnel[] | cdktf.IResolvable;
    /**
     * widget_heatmap block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_heatmap OneDashboard#widget_heatmap}
     *
     * @stability stable
     */
    readonly widgetHeatmap?: OneDashboardPageWidgetHeatmap[] | cdktf.IResolvable;
    /**
     * widget_histogram block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_histogram OneDashboard#widget_histogram}
     *
     * @stability stable
     */
    readonly widgetHistogram?: OneDashboardPageWidgetHistogram[] | cdktf.IResolvable;
    /**
     * widget_json block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_json OneDashboard#widget_json}
     *
     * @stability stable
     */
    readonly widgetJson?: OneDashboardPageWidgetJson[] | cdktf.IResolvable;
    /**
     * widget_line block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_line OneDashboard#widget_line}
     *
     * @stability stable
     */
    readonly widgetLine?: OneDashboardPageWidgetLine[] | cdktf.IResolvable;
    /**
     * widget_markdown block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_markdown OneDashboard#widget_markdown}
     *
     * @stability stable
     */
    readonly widgetMarkdown?: OneDashboardPageWidgetMarkdown[] | cdktf.IResolvable;
    /**
     * widget_pie block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_pie OneDashboard#widget_pie}
     *
     * @stability stable
     */
    readonly widgetPie?: OneDashboardPageWidgetPie[] | cdktf.IResolvable;
    /**
     * widget_stacked_bar block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_stacked_bar OneDashboard#widget_stacked_bar}
     *
     * @stability stable
     */
    readonly widgetStackedBar?: OneDashboardPageWidgetStackedBar[] | cdktf.IResolvable;
    /**
     * widget_table block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard#widget_table OneDashboard#widget_table}
     *
     * @stability stable
     */
    readonly widgetTable?: OneDashboardPageWidgetTable[] | cdktf.IResolvable;
}
export declare function oneDashboardPageToTerraform(struct?: OneDashboardPage | cdktf.IResolvable): any;
/**
 * Represents a {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard newrelic_one_dashboard}.
 *
 * @stability stable
 */
export declare class OneDashboard extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/newrelic/r/one_dashboard newrelic_one_dashboard} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: OneDashboardConfig);
    private _accountId?;
    /**
     * @stability stable
     */
    get accountId(): number;
    /**
     * @stability stable
     */
    set accountId(value: number);
    /**
     * @stability stable
     */
    resetAccountId(): void;
    /**
     * @stability stable
     */
    get accountIdInput(): number | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get guid(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get permalink(): string;
    private _permissions?;
    /**
     * @stability stable
     */
    get permissions(): string;
    /**
     * @stability stable
     */
    set permissions(value: string);
    /**
     * @stability stable
     */
    resetPermissions(): void;
    /**
     * @stability stable
     */
    get permissionsInput(): string | undefined;
    private _page?;
    /**
     * @stability stable
     */
    get page(): OneDashboardPage[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set page(value: OneDashboardPage[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get pageInput(): cdktf.IResolvable | OneDashboardPage[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
